==> nmsg-0.2.9.tar.gz: nmsg-0.2.9/nmsg/res.h <==
/*
 * Copyright (c) 2008 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef NMSG_RES_H
#define NMSG_RES_H

/*****
 ***** Module Info
 *****/

/*! \file nmsg/res.h
 * \brief Possible result codes for nmsg functions.
 */

typedef enum {
	nmsg_res_success,		/*%< success */
	nmsg_res_failure,		/*%< generic failure */
	nmsg_res_eof,			/*%< end of file */
	nmsg_res_memfail,		/*%< out of memory */
	nmsg_res_magic_mismatch,	/*%< nmsg header magic incorrect */
	nmsg_res_version_mismatch,	/*%< nmsg header version incorrect */
	nmsg_res_pbuf_ready,		/*%< a pbuf is ready to be written */
	nmsg_res_pbuf_written,		/*%< a pbuf has been written */
	nmsg_res_notimpl,		/*%< module lacks a function */
	nmsg_res_stop,			/*%< processing should stop */
	nmsg_res_trunc,			/*%< message should be truncated */
	nmsg_res_again,			/*%< caller should try again */
	nmsg_res_parse_error		/*%< unable to parse input */
} nmsg_res;

#endif /* NMSG_RES_H */

==> nmsg-0.3.0-pre1.tar.gz: nmsg-0.3.0-pre1/nmsg/res.h <==
/*
 * Copyright (c) 2008 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef NMSG_RES_H
#define NMSG_RES_H

/*****
 ***** Module Info
 *****/

/*! \file nmsg/res.h
 * \brief Possible result codes for nmsg functions.
 */

enum nmsg_res {
	nmsg_res_success,		/*%< success */
	nmsg_res_failure,		/*%< generic failure */
	nmsg_res_eof,			/*%< end of file */
	nmsg_res_memfail,		/*%< out of memory */
	nmsg_res_magic_mismatch,	/*%< nmsg header magic incorrect */
	nmsg_res_version_mismatch,	/*%< nmsg header version incorrect */
	nmsg_res_pbuf_ready,		/*%< a pbuf is ready to be written */
	nmsg_res_nmsg_written,		/*%< an nmsg container has been written */
	nmsg_res_notimpl,		/*%< module lacks a function */
	nmsg_res_stop,			/*%< processing should stop */
	nmsg_res_again,			/*%< caller should try again */
	nmsg_res_parse_error,		/*%< unable to parse input */
	nmsg_res_pcap_error		/*%< libpcap error */
};

extern const char *nmsg_res_strings[];

#endif /* NMSG_RES_H */
